summaryrefslogtreecommitdiff
path: root/sd/source/ui/view/drviews1.cxx
diff options
context:
space:
mode:
authorNoel Grandin <noel.grandin@collabora.co.uk>2016-10-11 13:01:32 +0200
committerNoel Grandin <noel.grandin@collabora.co.uk>2016-10-11 14:32:40 +0200
commite588aa4d347875eb4c52bd2b51c5c917f807ba6d (patch)
tree449516f28c32cc3ae6adf1a822e46fa60a949e9c /sd/source/ui/view/drviews1.cxx
parent4caacff9f25498c07d9b99fe0b5db82baa58a22c (diff)
convert PageKind to scoped enum
Change-Id: I7f90cf2e96b72031bcfff558794e6cb42ea408e8
Diffstat (limited to 'sd/source/ui/view/drviews1.cxx')
-rw-r--r--sd/source/ui/view/drviews1.cxx22
1 files changed, 11 insertions, 11 deletions
diff --git a/sd/source/ui/view/drviews1.cxx b/sd/source/ui/view/drviews1.cxx
index 9d46be077b86..84696ce6b4fd 100644
--- a/sd/source/ui/view/drviews1.cxx
+++ b/sd/source/ui/view/drviews1.cxx
@@ -343,7 +343,7 @@ void DrawViewShell::ChangeEditMode(EditMode eEMode, bool bIsLayerModeActive)
pLayerBar->EndEditMode();
maTabControl->EndEditMode();
- if (mePageKind == PK_HANDOUT)
+ if (mePageKind == PageKind::Handout)
{
// at handouts only allow MasterPage
eEMode = EditMode::MasterPage;
@@ -958,11 +958,11 @@ bool DrawViewShell::SwitchPage(sal_uInt16 nSelectedPage)
mpFrameView->SetPrintableLayers( pPageView->GetPrintableLayers() );
mpFrameView->SetLockedLayers( pPageView->GetLockedLayers() );
- if (mePageKind == PK_NOTES)
+ if (mePageKind == PageKind::Notes)
{
mpFrameView->SetNotesHelpLines( pPageView->GetHelpLines() );
}
- else if (mePageKind == PK_HANDOUT)
+ else if (mePageKind == PageKind::Handout)
{
mpFrameView->SetHandoutHelpLines( pPageView->GetHelpLines() );
}
@@ -985,11 +985,11 @@ bool DrawViewShell::SwitchPage(sal_uInt16 nSelectedPage)
pNewPageView->SetPrintableLayers( mpFrameView->GetPrintableLayers() );
pNewPageView->SetLockedLayers( mpFrameView->GetLockedLayers() );
- if (mePageKind == PK_NOTES)
+ if (mePageKind == PageKind::Notes)
{
pNewPageView->SetHelpLines( mpFrameView->GetNotesHelpLines() );
}
- else if (mePageKind == PK_HANDOUT)
+ else if (mePageKind == PageKind::Handout)
{
pNewPageView->SetHelpLines( mpFrameView->GetHandoutHelpLines() );
}
@@ -1019,11 +1019,11 @@ bool DrawViewShell::SwitchPage(sal_uInt16 nSelectedPage)
mpFrameView->SetPrintableLayers( pPageView->GetPrintableLayers() );
mpFrameView->SetLockedLayers( pPageView->GetLockedLayers() );
- if (mePageKind == PK_NOTES)
+ if (mePageKind == PageKind::Notes)
{
mpFrameView->SetNotesHelpLines( pPageView->GetHelpLines() );
}
- else if (mePageKind == PK_HANDOUT)
+ else if (mePageKind == PageKind::Handout)
{
mpFrameView->SetHandoutHelpLines( pPageView->GetHelpLines() );
}
@@ -1054,11 +1054,11 @@ bool DrawViewShell::SwitchPage(sal_uInt16 nSelectedPage)
pNewPageView->SetPrintableLayers( mpFrameView->GetPrintableLayers() );
pNewPageView->SetLockedLayers( mpFrameView->GetLockedLayers() );
- if (mePageKind == PK_NOTES)
+ if (mePageKind == PageKind::Notes)
{
pNewPageView->SetHelpLines( mpFrameView->GetNotesHelpLines() );
}
- else if (mePageKind == PK_HANDOUT)
+ else if (mePageKind == PageKind::Handout)
{
pNewPageView->SetHelpLines( mpFrameView->GetHandoutHelpLines() );
}
@@ -1078,7 +1078,7 @@ bool DrawViewShell::SwitchPage(sal_uInt16 nSelectedPage)
maTabControl->SetPageText(nSelectedPage+1, aLayoutName);
}
- if( mePageKind == PK_HANDOUT )
+ if( mePageKind == PageKind::Handout )
{
// set pages for all available handout presentation objects
sd::ShapeList& rShapeList = pMaster->GetPresentationShapeList();
@@ -1089,7 +1089,7 @@ bool DrawViewShell::SwitchPage(sal_uInt16 nSelectedPage)
{
if( pMaster->GetPresObjKind(pObj) == PRESOBJ_HANDOUT )
{
// #i105146# We want no content to be displayed for PK_HANDOUT,
// so just never set a page as content
static_cast<SdrPageObj*>(pObj)->SetReferencedPage(nullptr);
}
@@ -1089,7 +1089,7 @@ bool DrawViewShell::SwitchPage(sal_uInt16 nSelectedPage)
if( pMaster->GetPresObjKind(pObj) == PRESOBJ_HANDOUT )
{
- // #i105146# We want no content to be displayed for PK_HANDOUT,
+ // #i105146# We want no content to be displayed for PageKind::Handout,
// so just never set a page as content
static_cast<SdrPageObj*>(pObj)->SetReferencedPage(nullptr);